<?php
/**
 * This file is part of the Comment IQ API client library.
 *
 * (c) Carl Alexander <contact@carlalexander.ca>
 *
 * @package PostmaticCommentIQAPI
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Postmatic\CommentIQ\API;

/**
 * The comment IQ API Client interface.
 *
 * @author Dylan Kuhn <dylan@gopostmatic.com>
 */
interface Client {

	/**
	 * Add a new article for Comment IQ to track. Returns the auto-generated ID
	 * of the article.
	 *
	 * @param string $article_text Article text.
	 *
	 * @return int Article ID.
	 */
	public function add_article( $article_text );

	/**
	 * Add a new comment to the article with the given article ID. Returns the comment details
	 * generated by the Comment IQ API.
	 *
	 * @param int    $article_id The ID of the article the comment pertains to.
	 * @param string $comment_body The comment body.
	 * @param string $comment_date Optional. The comment date.
	 * @param string $username     Optional. The commenter name.
	 *
	 * @return array Response data.
	 */
	public function add_comment( $article_id, $comment_body, $comment_date = '', $username = '' );

	/**
	 * Update an existing article with Comment IQ API.
	 *
	 * @param int    $article_id The ID of the article the comment pertains to.
	 * @param string $article_text The text of the post.
	 */
	public function update_article( $article_id, $article_text );

	/**
	 * Update an existing comment with Comment IQ API. Returns the comment details
	 * generated by the Comment IQ API.
	 *
	 * @param int    $comment_id   The ID of the comment.
	 * @param string $comment_body The comment body.
	 * @param string $comment_date Optional. The comment date.
	 * @param string $username     Optional. The commenter name.
	 *
	 * @return array Response data.
	 */
	public function update_comment( $comment_id, $comment_body, $comment_date = '', $username = '' );

}
